<?php
/*
Plugin Name: ChatZap
Description: Add a WhatsApp click-to-chat button to your website with an activate/deactivate toggle and customizable options.
Version: 1.0
Author: Rajeevdaz
Author URI: https://rajeevdaz.com/
*/

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Add menu item in the WordPress admin
add_action('admin_menu', 'chatzap_add_admin_menu');

function chatzap_add_admin_menu() {
    add_menu_page(
        'ChatZap Settings',       // Page title
        'ChatZap',                // Menu title
        'manage_options',         // Capability
        'chatzap-settings',       // Menu slug
        'chatzap_settings_page',  // Callback function
        'dashicons-whatsapp',     // Icon
        100                       // Position
    );
}

// Include the settings page
function chatzap_settings_page() {
    include plugin_dir_path(__FILE__) . 'settings.php';
}

// Add the WhatsApp chat icon only if the toggle is "on"
add_action('wp_footer', 'chatzap_add_whatsapp_button');

function chatzap_add_whatsapp_button() {
    $toggle_status = get_option('chatzap_toggle_status', 'off');
    if ($toggle_status === 'on') {
        $phone_number = get_option('chatzap_phone_number', '');
        $message = urlencode(get_option('chatzap_message', 'Hi there! I am interested in your services.'));
        $icon_size = get_option('chatzap_icon_size', 40);
        $icon_url = plugin_dir_url(__FILE__) . 'src/WhatsApp.svg';

        echo '<a href="#" id="chatzap-whatsapp-button" style="position: fixed; bottom: 20px; right: 20px; z-index: 9999; border-radius: 50%; background-color: #25D366; padding: 10px; box-shadow: 0px 4px 6px rgba(0, 0, 0, 0.2); transition: transform 0.3s ease;">
                <img src="' . esc_url($icon_url) . '" alt="WhatsApp" style="width:' . intval($icon_size) . 'px; height:' . intval($icon_size) . 'px;">
              </a>
              <script>
                document.getElementById("chatzap-whatsapp-button").addEventListener("click", function() {
                    var isMobile = /iPhone|iPad|iPod|Android/i.test(navigator.userAgent);
                    var waLink = isMobile ? "https://wa.me/' . esc_js($phone_number) . '?text=' . esc_js($message) . '" : "https://web.whatsapp.com/send?phone=' . esc_js($phone_number) . '&text=' . esc_js($message) . '";
                    window.open(waLink, "_blank");
                });
              </script>
              <style>
                #chatzap-whatsapp-button:hover {
                    transform: scale(1.1);
                }
              </style>';
    }
}

// Register settings on plugin activation
register_activation_hook(__FILE__, 'chatzap_activate');

function chatzap_activate() {
    add_option('chatzap_toggle_status', 'off'); // Default: Deactivated
    add_option('chatzap_phone_number', ''); 
    add_option('chatzap_message', 'Hi there! I am interested in your services.'); // Default message
    add_option('chatzap_icon_size', 40); // Default WhatsApp icon size in pixels
}

// Clean up settings on plugin deactivation
register_deactivation_hook(__FILE__, 'chatzap_deactivate');

function chatzap_deactivate() {
    delete_option('chatzap_toggle_status');
    delete_option('chatzap_phone_number');
    delete_option('chatzap_message');
    delete_option('chatzap_icon_size');
}

// Add custom links (YouTube channel) to the plugin row on the plugins page
add_filter('plugin_action_links', 'chatzap_add_custom_plugin_links', 10, 2);

function chatzap_add_custom_plugin_links($links, $file) {
    // Make sure it's for this plugin
    if (plugin_basename(__FILE__) === $file) {
        // Add YouTube channel link
        $youtube_channel_link = '<a href="https://youtube.com/@Rajeevdaz" target="_blank">YouTube Channel</a>';
        
        // Append the custom link
        $links[] = $youtube_channel_link;
    }
    return $links;
}
?>
