<?php
if (!defined('ABSPATH')) {
    exit;
}

// Save settings when form is submitted
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['chatzap_save_settings'])) {
    update_option('chatzap_toggle_status', sanitize_text_field($_POST['chatzap_toggle_status']));
    update_option('chatzap_phone_number', sanitize_text_field($_POST['chatzap_phone_number']));
    update_option('chatzap_message', sanitize_text_field($_POST['chatzap_message']));
    update_option('chatzap_icon_size', intval($_POST['chatzap_icon_size']));
}

// Get current settings
$toggle_status = get_option('chatzap_toggle_status', 'off');
$phone_number = get_option('chatzap_phone_number', '');
$message = get_option('chatzap_message', 'Hi there! I am interested in your services.');
$icon_size = get_option('chatzap_icon_size', 40);
?>

<div class="wrap">
    <h1>ChatZap Settings</h1>
    <form method="post" action="">
        <table class="form-table">
            <tr>
                <th scope="row">Activate WhatsApp Button</th>
                <td>
                    <label class="switch">
                        <input type="checkbox" name="chatzap_toggle_status" value="on" <?php echo $toggle_status === 'on' ? 'checked' : ''; ?>>
                        <span class="slider round"></span>
                    </label>
                </td>
            </tr>
            <tr>
                <th scope="row">WhatsApp Phone Number</th>
                <td>
                    <input type="text" name="chatzap_phone_number" value="<?php echo esc_attr($phone_number); ?>" class="regular-text">
                    <p class="description">Enter your WhatsApp phone number (with country code, e.g., 919876543210).</p>
                </td>
            </tr>
            <tr>
                <th scope="row">Default Message</th>
                <td>
                    <textarea name="chatzap_message" class="large-text"><?php echo esc_textarea($message); ?></textarea>
                    <p class="description">Enter the default message that will appear when someone clicks the WhatsApp button.</p>
                </td>
            </tr>
            <tr>
                <th scope="row">WhatsApp Icon Size</th>
                <td>
                    <input type="number" name="chatzap_icon_size" value="<?php echo intval($icon_size); ?>" class="small-text"> px
                    <p class="description">Set the size of the WhatsApp icon in pixels (default: 40px).</p>
                </td>
            </tr>
        </table>
        <?php submit_button('Save Changes', 'primary', 'chatzap_save_settings'); ?>
    </form>
</div>

<style>
/* Toggle switch styling */
.switch {
    position: relative;
    display: inline-block;
    width: 40px;
    height: 20px;
}

.switch input {
    display: none;
}

.slider {
    position: absolute;
    cursor: pointer;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background-color: #ccc;
    transition: .4s;
    border-radius: 20px;
}

.slider:before {
    position: absolute;
    content: "";
    height: 14px;
    width: 14px;
    left: 3px;
    bottom: 3px;
    background-color: white;
    transition: .4s;
    border-radius: 50%;
}

input:checked + .slider {
    background-color: #0073aa;
}

input:checked + .slider:before {
    transform: translateX(20px);
}
</style>
